import * as i0 from '@angular/core';
import { Component, Input, NgModule } from '@angular/core';
import { fadeInOnEnterAnimation, fadeOutOnLeaveAnimation } from 'angular-animations';
import { asyncScheduler } from 'rxjs';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from 'ngx-highlightjs';
import { HighlightModule, HighlightAuto, provideHighlightOptions } from 'ngx-highlightjs';
import * as i3 from 'ngx-highlightjs/line-numbers';
import { HighlightLineNumbers } from 'ngx-highlightjs/line-numbers';

class CodeSnippetComponent {
    /** Manually set language of the code */
    set setLanguage(language) {
        this.language = language;
        this.autoHighlight = false;
    }
    constructor() {
        /** Code snippet to display */
        this.code = '';
        /** Indicates when copy button should be shown */
        this.showCopy = true;
        /** Show line numbers */
        this.showLineNumbers = false;
        /** Manually set language of the code */
        this.language = '';
        /** Indicates whether to use auto highlighting */
        this.autoHighlight = true;
        /** Whether copy button has been pressed */
        this.copiedToClipboard = false;
        /** Length of time in which copied text appears (ms) */
        this.copiedTextLength = 2000;
    }
    /**
     * On destroy lifecycle hook
     */
    ngOnDestroy() {
        this.copyTextSub?.unsubscribe();
    }
    /**
     * Copies code to the clipboard
     */
    copyToClipboard() {
        navigator.clipboard.writeText(this.code);
        this.copiedToClipboard = true;
        this.copyTextSub = asyncScheduler.schedule(() => (this.copiedToClipboard = false), this.copiedTextLength);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: CodeSnippetComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.12", type: CodeSnippetComponent, selector: "code-snippet", inputs: { code: "code", showCopy: "showCopy", showLineNumbers: "showLineNumbers", setLanguage: ["language", "setLanguage"] }, ngImport: i0, template: "<!-- Snippet -->\n<pre *ngIf=\"autoHighlight && showLineNumbers\"><code class=\"code-container\" [highlightAuto]=\"code\" lineNumbers></code></pre>\n<pre *ngIf=\"autoHighlight && !showLineNumbers\"><code class=\"code-container\" [highlightAuto]=\"code\"></code></pre>\n<pre\n    *ngIf=\"!autoHighlight && showLineNumbers\"\n><code class=\"code-container\" [highlight]=\"code\" [language]=\"language\" lineNumbers></code></pre>\n<pre *ngIf=\"!autoHighlight && !showLineNumbers\"><code class=\"code-container\" [highlight]=\"code\" [language]=\"language\"></code></pre>\n\n<!-- Copy to Clipboard -->\n<div *ngIf=\"showCopy\" class=\"clipboard-container\">\n    <span *ngIf=\"copiedToClipboard\" class=\"copied-text\" [@fadeInOnEnter] [@fadeOutOnLeave]>Copied!</span>\n    <button class=\"copy-button\" title=\"Copy to clipboard.\" (click)=\"copyToClipboard()\">\n        <i class=\"eva\" [class]=\"copiedToClipboard ? 'eva-checkmark-outline' : 'eva-copy-outline'\"></i>\n    </button>\n</div>\n", styles: [":host{position:relative;width:100%}:host ::ng-deep .hljs-ln-numbers{opacity:.5}:host ::ng-deep .hljs-ln tr{display:grid;grid-template-columns:min-content auto;column-gap:10px}.code-container{font-size:.8rem;min-height:48px;border-radius:8px}.clipboard-container{position:absolute;top:.5em;right:.5em;z-index:1;display:flex}.copied-text{display:flex;align-items:center;font-size:.85rem;color:#fff;background-color:#0d1117;padding:0 5px;margin:0 5px}.copy-button{min-width:30px;display:flex;align-items:center;justify-content:center;color:#fff;padding:5px;font-size:1.125rem;border:1px solid rgba(255,255,255,.1333333333);border-radius:.25rem;outline:none;background-color:#3a394d}.copy-button:hover{cursor:pointer}.copy-button:focus-visible{outline:-webkit-focus-ring-color auto 1px}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.Highlight, selector: "[highlight]", inputs: ["highlight", "language", "ignoreIllegals"], outputs: ["highlighted"] }, { kind: "directive", type: i2.HighlightAuto, selector: "[highlightAuto]", inputs: ["highlightAuto", "languages"], outputs: ["highlighted"] }, { kind: "directive", type: i3.HighlightLineNumbers, selector: "[highlight][lineNumbers], [highlightAuto][lineNumbers]", inputs: ["startFrom", "singleLine"] }], animations: [fadeInOnEnterAnimation(), fadeOutOnLeaveAnimation()] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: CodeSnippetComponent, decorators: [{
            type: Component,
            args: [{ selector: 'code-snippet', animations: [fadeInOnEnterAnimation(), fadeOutOnLeaveAnimation()], template: "<!-- Snippet -->\n<pre *ngIf=\"autoHighlight && showLineNumbers\"><code class=\"code-container\" [highlightAuto]=\"code\" lineNumbers></code></pre>\n<pre *ngIf=\"autoHighlight && !showLineNumbers\"><code class=\"code-container\" [highlightAuto]=\"code\"></code></pre>\n<pre\n    *ngIf=\"!autoHighlight && showLineNumbers\"\n><code class=\"code-container\" [highlight]=\"code\" [language]=\"language\" lineNumbers></code></pre>\n<pre *ngIf=\"!autoHighlight && !showLineNumbers\"><code class=\"code-container\" [highlight]=\"code\" [language]=\"language\"></code></pre>\n\n<!-- Copy to Clipboard -->\n<div *ngIf=\"showCopy\" class=\"clipboard-container\">\n    <span *ngIf=\"copiedToClipboard\" class=\"copied-text\" [@fadeInOnEnter] [@fadeOutOnLeave]>Copied!</span>\n    <button class=\"copy-button\" title=\"Copy to clipboard.\" (click)=\"copyToClipboard()\">\n        <i class=\"eva\" [class]=\"copiedToClipboard ? 'eva-checkmark-outline' : 'eva-copy-outline'\"></i>\n    </button>\n</div>\n", styles: [":host{position:relative;width:100%}:host ::ng-deep .hljs-ln-numbers{opacity:.5}:host ::ng-deep .hljs-ln tr{display:grid;grid-template-columns:min-content auto;column-gap:10px}.code-container{font-size:.8rem;min-height:48px;border-radius:8px}.clipboard-container{position:absolute;top:.5em;right:.5em;z-index:1;display:flex}.copied-text{display:flex;align-items:center;font-size:.85rem;color:#fff;background-color:#0d1117;padding:0 5px;margin:0 5px}.copy-button{min-width:30px;display:flex;align-items:center;justify-content:center;color:#fff;padding:5px;font-size:1.125rem;border:1px solid rgba(255,255,255,.1333333333);border-radius:.25rem;outline:none;background-color:#3a394d}.copy-button:hover{cursor:pointer}.copy-button:focus-visible{outline:-webkit-focus-ring-color auto 1px}\n"] }]
        }], ctorParameters: () => [], propDecorators: { code: [{
                type: Input
            }], showCopy: [{
                type: Input
            }], showLineNumbers: [{
                type: Input
            }], setLanguage: [{
                type: Input,
                args: ['language']
            }] } });

class CodeSnippetModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: CodeSnippetModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.12", ngImport: i0, type: CodeSnippetModule, declarations: [CodeSnippetComponent], imports: [CommonModule, HighlightModule, HighlightAuto, HighlightLineNumbers], exports: [CodeSnippetComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: CodeSnippetModule, providers: [
            provideHighlightOptions({
                fullLibraryLoader: () => import('highlight.js'),
                lineNumbersLoader: () => import('ngx-highlightjs/line-numbers'),
            }),
        ], imports: [CommonModule, HighlightModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: CodeSnippetModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [CodeSnippetComponent],
                    imports: [CommonModule, HighlightModule, HighlightAuto, HighlightLineNumbers],
                    exports: [CodeSnippetComponent],
                    providers: [
                        provideHighlightOptions({
                            fullLibraryLoader: () => import('highlight.js'),
                            lineNumbersLoader: () => import('ngx-highlightjs/line-numbers'),
                        }),
                    ],
                }]
        }] });

/*
 * Public API Surface of ngx-code-snippet
 */

/**
 * Generated bundle index. Do not edit.
 */

export { CodeSnippetComponent, CodeSnippetModule };
//# sourceMappingURL=ngx-code-snippet.mjs.map
